@@ -6,7 +6,15 @@ from typing import Any
 from litefeel.pycommon.io import read_file
 
 from .config import Config
-from .subcommands import adbdevice, adbpush, apkinfo, apkinstall, apkuninstall
+from .subcommands import (
+    adbdevice,
+    adbpush,
+    apkinfo,
+    apkinstall,
+    apkuninstall,
+    apksigner,
+    assetbundleinfo,
+)
 
 _VERSION_FILE_NAME = "version.txt"
 
@@ -24,7 +32,7 @@ class Command:
         self.help = help
 
 
-def addsubcommands(subparser: argparse._SubParsersAction, commands: list[Command]):
+def addsubcommands(subparser: argparse._SubParsersAction, commands: list[Command]) -> None:
     for cmd in commands:
         parser = subparser.add_parser(cmd.name, help=cmd.help)
         parser.set_defaults(docommand=cmd.command.docommand)
@@ -51,6 +59,8 @@ def main(_args=None):
         Command("install", apkinstall, "install apk file"),
         Command("uninstall", apkuninstall, "uninstall apk file"),
         Command("apk", apkinfo, "show apk packageName/activityName"),
+        Command("sign", apksigner, "sign apk with android debug(only windows)"),
+        Command("ab", assetbundleinfo, "extract unity asset bundle information"),
     ]
 
     subparser = parser.add_subparsers(title="sub commands", dest="subcommand")
